Authors
=======

Lead Developers
---------------
- `Yalin Li <mailto:mailto:zoe.yalin.li@gmail.com>`_ (current maintainer)
- `Joy Cheung <mailto:joycheung1994@gmail.com>`_


Code Development
----------------
- `Yalin Li <mailto:zoe.yalin.li@gmail.com>`_
- `Joy Cheung <mailto:joycheung1994@gmail.com>`_
- `Other developers <https://github.com/QSD-Group/QSDsan/graphs/contributors>`_ that have contributed to the repository.


Module Development
------------------
- `Yalin Li <mailto:zoe.yalin.li@gmail.com>`_
- `Joy Cheung <mailto:joycheung1994@gmail.com>`_
- Stetson Rowles
- Tori Morgan
- Hannah Lohman
- Smiti Mittal
- Anna Kogler
- Samuel Aguiar
- Tyler Stephen
- Shion Watabe


Project Conception
------------------
- `Jeremy Guest <mailto:jsguest@illinois.edu>`_


Funding Support
---------------
- `Jeremy Guest <mailto:jsguest@illinois.edu>`_


Special Acknowledgement
-----------------------
- Yoel Cortés-Peña for helping many of the ``QSDsan`` members get started on Python and package development.
